==========================================
``psyclone.psyir.symbols.containersymbol``
==========================================

.. automodule:: psyclone.psyir.symbols.containersymbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.containersymbol


Classes
=======

- :py:class:`ContainerSymbol`:
  Symbol that represents a reference to a Container. The reference

- :py:class:`ContainerSymbolInterface`:
  Abstract implementation of the ContainerSymbol Interface 

- :py:class:`FortranModuleInterface`:
  Implementation of ContainerSymbolInterface for Fortran modules 


.. autoclass:: ContainerSymbol
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ContainerSymbol
      :parts: 1

.. autoclass:: ContainerSymbolInterface
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ContainerSymbolInterface
      :parts: 1

.. autoclass:: FortranModuleInterface
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: FortranModuleInterface
      :parts: 1
